# -*- coding: utf-8 -*-

from imio.smartweb.common.utils import get_vocabulary
from imio.smartweb.locales import SmartwebMessageFactory as _
from plone import api
from plone.portlets.interfaces import IPortletAssignmentMapping
from plone.portlets.interfaces import IPortletManager
from z3c.form.interfaces import IFormLayer
from zope.component import getMultiAdapter
from zope.component import getUtility
from zope.globalrequest import getRequest
from zope.i18n import translate
from zope.interface import alsoProvides


def remove_unused_contents(portal):
    api.content.delete(portal.news)
    api.content.delete(portal.events)
    api.content.delete(portal.Members)


def clear_manager_portlets(folder, manager_name):
    manager = getUtility(IPortletManager, name=manager_name, context=folder)
    assignments = getMultiAdapter((folder, manager), IPortletAssignmentMapping)
    for portlet in assignments:
        del assignments[portlet]


def add_iam_folder(context, current_lang):
    i_am_folder = api.content.create(
        container=context,
        type="imio.smartweb.Folder",
        title=translate(_("I am"), target_language=current_lang),
    )
    api.content.transition(i_am_folder, "publish")

    i_am_vocabulary = get_vocabulary("imio.smartweb.vocabulary.IAm")
    for term in i_am_vocabulary:
        link = api.content.create(
            container=i_am_folder,
            type="Link",
            title=translate(_(term.title), target_language=current_lang),
        )
        link.remoteUrl = "{0}/@@search?iam={1}".format("${portal_url}", term.token)
        api.content.transition(link, "publish")


def add_ifind_folder(context, current_lang):
    i_find_folder = api.content.create(
        container=context,
        type="imio.smartweb.Folder",
        title=translate(_("I find"), target_language=current_lang),
    )
    api.content.transition(i_find_folder, "publish")
    collection = api.content.create(
        container=i_find_folder,
        type="Collection",
        title=translate(
            _("Procedures and practical informations"), target_language=current_lang
        ),
    )
    collection.query = [
        {
            "i": "portal_type",
            "o": "plone.app.querystring.operation.selection.any",
            "v": ["imio.smartweb.Procedure"],
        }
    ]
    api.content.transition(collection, "publish")
    request = getRequest()
    alsoProvides(request, IFormLayer)
    request.form = {
        "cid": "page-category",
        "faceted.page-category.index": "taxonomy_procedure_category",
        "faceted.page-category.vocabulary": "collective.taxonomy.procedure_category",
    }
    handler = getMultiAdapter((collection, request), name="faceted_update_criterion")
    handler.edit(**request.form)


def add_navigation_links(context):
    current_lang = api.portal.get_current_language()[:2]
    add_iam_folder(context, current_lang)
    add_ifind_folder(context, current_lang)



# -*- coding: utf-8 -*-

from Products.CMFPlone.patterns.settings import PatternSettingsAdapter
from zope.component import getUtility
from zope.i18n import translate
from zope.schema.interfaces import IVocabularyFactory

import json


EXCLUDED_TINY_MCE_SCALES = ["tile", "icon", "listing"]


class SmartwebPatternSettingsAdapter(PatternSettingsAdapter):
    """
    Provides only useful scales for Tiny MCE image modal.
    """

    @property
    def image_scales(self):
        factory = getUtility(IVocabularyFactory, "plone.app.vocabularies.ImagesScales")
        vocabulary = factory(self.context)
        ret = [
            {"title": translate(it.title), "value": it.value}
            for it in vocabulary
            if it.value not in EXCLUDED_TINY_MCE_SCALES
        ]
        ret = sorted(ret, key=lambda it: it["title"])
        return json.dumps(ret)



# -*- coding: utf-8 -*-
from plone.app.contenttypes.testing import PLONE_APP_CONTENTTYPES_FIXTURE
from plone.app.robotframework.testing import REMOTE_LIBRARY_BUNDLE_FIXTURE
from plone.app.testing import (
    applyProfile,
    FunctionalTesting,
    IntegrationTesting,
    PloneSandboxLayer,
)
from plone.testing import z2
from z3c.form.interfaces import IFormLayer
from zope.globalrequest import setRequest
from zope.interface import alsoProvides

import imio.smartweb.policy


class ImioSmartwebPolicyLayer(PloneSandboxLayer):

    defaultBases = (PLONE_APP_CONTENTTYPES_FIXTURE,)

    def setUpZope(self, app, configurationContext):
        # Load any other ZCML that is required for your tests.
        # The z3c.autoinclude feature is disabled in the Plone fixture base
        # layer.
        self.loadZCML(package=imio.smartweb.policy)

    def setUpPloneSite(self, portal):
        request = portal.REQUEST
        # set basic request to be able to handle redirect in subscribers
        setRequest(request)
        alsoProvides(request, IFormLayer)
        applyProfile(portal, "imio.smartweb.policy:default")


IMIO_SMARTWEB_POLICY_FIXTURE = ImioSmartwebPolicyLayer()


IMIO_SMARTWEB_POLICY_INTEGRATION_TESTING = IntegrationTesting(
    bases=(IMIO_SMARTWEB_POLICY_FIXTURE,),
    name="ImioSmartwebPolicyLayer:IntegrationTesting",
)


IMIO_SMARTWEB_POLICY_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(IMIO_SMARTWEB_POLICY_FIXTURE,),
    name="ImioSmartwebPolicyLayer:FunctionalTesting",
)


IMIO_SMARTWEB_POLICY_ACCEPTANCE_TESTING = FunctionalTesting(
    bases=(
        IMIO_SMARTWEB_POLICY_FIXTURE,
        REMOTE_LIBRARY_BUNDLE_FIXTURE,
        z2.ZSERVER_FIXTURE,
    ),
    name="ImioSmartwebPolicyLayer:AcceptanceTesting",
)



# -*- coding: utf-8 -*-

from imio.smartweb.policy.utils import add_iam_folder
from plone import api
from plone.app.workflow.remap import remap_workflow
from Products.CMFPlone.utils import get_installer
import logging

logger = logging.getLogger("imio.smartweb.policy")
PROFILEID = "profile-imio.smartweb.policy:default"


def configure_first_official_release(context):
    portal_setup = api.portal.get_tool("portal_setup")
    portal_setup.runAllImportStepsFromProfile("profile-pas.plugins.imio:default")
    portal_setup.runImportStepFromProfile(PROFILEID, "typeinfo")
    portal_setup.runImportStepFromProfile(PROFILEID, "viewlets")


def reload_types(context):
    portal_setup = api.portal.get_tool("portal_setup")
    portal_setup.runImportStepFromProfile(PROFILEID, "typeinfo")


def transform_old_iam_link_to_iam_folder(context):
    portal = api.portal.get()
    obj = portal.get("i-am") or portal.get("je-suis")
    if obj is not None:
        if obj.portal_type != "Link":
            return
        else:
            api.content.delete(obj=obj)
    current_lang = api.portal.get_current_language()[:2]
    add_iam_folder(portal, current_lang)


def restore_links_workflow(context):
    portal = api.portal.get()
    remap_workflow(portal, type_ids=("Link",), chain="(Default)")


def reload_viewlets(context):
    portal_setup = api.portal.get_tool("portal_setup")
    portal_setup.runImportStepFromProfile(PROFILEID, "viewlets")


def uninstall_z3cform_select2(context):
    installer = get_installer(context)
    installer.uninstall_product("collective.z3cform.select2")



# -*- coding: utf-8 -*-

from imio.smartweb.common.caching import ban_physicalpath
from plone import api
from plone.app.caching.operations.default import ModerateCaching
from plone.app.caching.operations.default import StrongCaching
from plone.app.caching.operations.default import TerseCaching
from plone.app.caching.operations.default import WeakCaching
from plone.caching.interfaces import ICachingOperationType
from plone.caching.utils import lookupOptions
from Products.CMFPlone.utils import parent
from zope.interface import provider

import logging

logger = logging.getLogger("imio.smartweb.policy")


def ban_for_message(obj, event):
    request = event.object.REQUEST
    portal = api.portal.get()
    physical_path = portal.getPhysicalPath()
    container = parent(obj)
    if container.portal_type != "MessagesConfig":
        # we are on a local message, ban only its container path
        physical_path = container.getPhysicalPath()
    ban_physicalpath(request, physical_path)


class PatchedCachingMixin:
    def interceptResponse(self, rulename, response, class_=None):
        result = super(PatchedCachingMixin, self).interceptResponse(
            rulename, response, class_
        )
        if result != "":
            # "" is the result of a 304 NOT MODIFIED
            return result

        options = lookupOptions(class_ or self.__class__, rulename)
        maxage = options.get("maxage", self.maxage)
        smaxage = options.get("smaxage", self.smaxage)

        if maxage:
            if smaxage is not None:
                maxage = f"{maxage}, s-maxage={smaxage}"
            response.setHeader(
                "Cache-Control",
                f"max-age={maxage}, proxy-revalidate, public",
            )
        elif smaxage:
            response.setHeader(
                "Cache-Control",
                f"max-age=0, s-maxage={smaxage}, must-revalidate",
            )
        else:
            response.setHeader("Cache-Control", "max-age=0, must-revalidate, private")

        return ""


@provider(ICachingOperationType)
class PatchedModerateCaching(PatchedCachingMixin, ModerateCaching):
    """Moderate caching with Cache-Control heaader set, even for 304"""


@provider(ICachingOperationType)
class PatchedStrongCaching(PatchedCachingMixin, StrongCaching):
    """Strong caching with Cache-Control heaader set, even for 304"""


@provider(ICachingOperationType)
class PatchedTerseCaching(PatchedCachingMixin, TerseCaching):
    """Terse caching with Cache-Control heaader set, even for 304"""


@provider(ICachingOperationType)
class PatchedWeakCaching(PatchedCachingMixin, WeakCaching):
    """Weak caching with Cache-Control heaader set, even for 304"""



# -*- coding: utf-8 -*-

from plone import api
from zope.component import getMultiAdapter
from zope.globalrequest import getRequest


def post_install(context):
    """Post install demo script"""
    portal = api.portal.get()
    request = getRequest()
    folder1 = api.content.create(
        container=portal,
        type="imio.smartweb.Folder",
        title="Folder 1",
    )
    api.content.transition(folder1, "publish")
    folder2 = api.content.create(
        container=portal,
        type="imio.smartweb.Folder",
        title="Folder 2",
    )
    api.content.transition(folder2, "publish")
    folder3 = api.content.create(
        container=portal,
        type="imio.smartweb.Folder",
        title="Folder 3",
    )
    api.content.transition(folder3, "publish")

    # Inside folder 1
    page1 = api.content.create(
        container=folder1,
        type="imio.smartweb.Page",
        title="Page 1",
    )
    api.content.transition(page1, "publish")
    api.content.create(
        container=page1,
        type="imio.smartweb.SectionText",
        title="My beautiful text section",
    )
    api.content.create(
        container=page1,
        type="imio.smartweb.SectionGallery",
        title="Squirel gallery",
    )

    # Inside folder 2
    page2 = api.content.create(
        container=folder2,
        type="imio.smartweb.Page",
        title="Page 2",
    )
    api.content.transition(page2, "publish")
    page3 = api.content.create(
        container=folder2,
        type="imio.smartweb.Page",
        title="Page 3",
    )
    api.content.transition(page3, "publish")

    # Inside folder 3
    subsite = api.content.create(
        container=folder3,
        type="imio.smartweb.Folder",
        title="Subsite",
    )
    api.content.transition(subsite, "publish")
    subsite_view = getMultiAdapter((subsite, request), name="subsite_settings")
    subsite_view.enable()
    page4 = api.content.create(
        container=subsite,
        type="imio.smartweb.Page",
        title="Page 4",
    )
    api.content.transition(page4, "publish")
    page5 = api.content.create(
        container=subsite,
        type="imio.smartweb.Page",
        title="Page 5",
    )
    api.content.transition(page5, "publish")



# -*- coding: utf-8 -*-
"""Installer for the imio.smartweb.policy package."""

from setuptools import find_packages
from setuptools import setup


long_description = "\n\n".join(
    [
        open("README.rst").read(),
        open("CONTRIBUTORS.rst").read(),
        open("CHANGES.rst").read(),
    ]
)


setup(
    name="imio.smartweb.policy",
    version="1.0.9",
    description="Policies to setup imio.smartweb",
    long_description=long_description,
    # Get more from https://pypi.org/classifiers/
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Plone :: Addon",
        "Framework :: Plone :: 6.0",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
    ],
    keywords="Python Plone CMS",
    author="Christophe Boulanger",
    author_email="christophe.boulanger@imio.be",
    url="https://github.com/imio/imio.smartweb.policy",
    project_urls={
        "PyPI": "https://pypi.python.org/pypi/imio.smartweb.policy",
        "Source": "https://github.com/imio/imio.smartweb.policy",
        "Tracker": "https://github.com/imio/imio.smartweb.policy/issues",
        # 'Documentation': 'https://imio.smartweb.policy.readthedocs.io/en/latest/',
    },
    license="GPL version 2",
    packages=find_packages("src", exclude=["ez_setup"]),
    namespace_packages=["imio", "imio.smartweb"],
    package_dir={"": "src"},
    include_package_data=True,
    zip_safe=False,
    python_requires=">=3.8",
    install_requires=[
        "setuptools",
        # -*- Extra requirements: -*-
        "z3c.jbot",
        "plone.api>=1.8.4",
        "plone.app.dexterity",
        "plone.app.imagecropping",
        "collective.autopublishing",
        "collective.autoscaling",
        "collective.big.bang",
        "collective.messagesviewlet",
        "collective.pivot",
        "collective.solr",
        "collective.themefragments",
        "collective.z3cform.select2",
        "eea.facetednavigation",
        "pas.plugins.imio",
        "imio.gdpr",
        "imio.smartweb.core",
        "imio.smartweb.locales",
        "imio.prometheus",
    ],
    extras_require={
        "test": [
            "plone.app.testing",
            # Plone KGS does not use this version, because it would break
            # Remove if your package shall be part of coredev.
            # plone_coredev tests as of 2016-04-01.
            "plone.testing>=5.0.0",
            "plone.app.contenttypes",
            "plone.app.robotframework[debug]",
        ],
    },
    entry_points="""
    [z3c.autoinclude.plugin]
    target = plone
    """,
)



from eea.facetednavigation.subtypes.interfaces import IFacetedSubtyper
from eea.facetednavigation.subtypes.subtyper import FacetedPublicSubtyper
from zope.interface import implementer


@implementer(IFacetedSubtyper)
class FolderFacetedPublicSubtyper(FacetedPublicSubtyper):
    """Deactivate faceted navigation on imio.smartweb.Folder content type."""

    @property
    def can_enable(self):
        """See IFacetedSubtyper"""
        return False

    @property
    def can_disable(self):
        """See IFacetedSubtyper"""
        return False

    def enable(self):
        """See IFacetedSubtyper"""
        return False

    def disable(self):
        """See IFacetedSubtyper"""
        return False



# -*- coding: utf-8 -*-

from AccessControl import allow_module, allow_class, allow_type
from requests.models import Response

# Useful for code used in RestrictedPython (collective.themefragments)
allow_module("requests")
allow_class(Response)
allow_type(type("requests.models.Response"))
